local bstr = function(id, val)
	return val
end

local babel, lang_key
local do_babel_support = function()
	if lib.is_ready("babel", "0") then
		babel = lib.get_class("babel", "0")
		lang_key = babel.register("plugins/reskin/lang", {'en', 'es', 'fr', 'pt'})
		
		bstr = function(id, val)
			return babel.fetch(lang_key, id, val)
		end
	end
end


local clip = {
	CCD1 = true,
	open = nil,
	config = nil,
	smart_config = {
		title = bstr(1, "Clipboard Saver"),
		cb = function() end,
		[1] = 'no_config',
		no_config = {
			type = "text",
			align = "right",
			display = bstr(2, "Cliboard Saver has no configuration options"),
		},
	},
	description = bstr(3, "Clipboard Saver is an import/export system to assist pilots on limited platforms. Clipboard Saver stores system notes to the user's clipboard to allow backup externally, and importing through the reverse."),
	commands = {
		"/clipsave",
	},
	manifest = {
		"plugins/ClipSaver/main.lua",
		"plugins/ClipSaver/core.lua",
		"plugins/ClipSaver/clip.ini",
		"plugins/ClipSaver/lang/en.lua",
		"plugins/ClipSaver/lang/es.lua",
		"plugins/ClipSaver/lang/fr.lua",
		"plugins/ClipSaver/lang/pt.lua",
	},
	
	--public functions
	
	add_preset = nil,
}

local note_presets = {}

clip.add_preset = function(id, name)
	table.insert(note_presets, {
		[1] = id,
		[2] = name,
	})
end

--Add systemnotes and known plugins
for i=1, 33 do
	if SystemNames[i] then
		clip.add_preset(i, SystemNames[i] .. bstr(4, " sector notes"))
	end
end
clip.add_preset(37643, "DroidButtons " .. bstr(5, "configuration"))
-------------------------------------

clip.open = function()
	local select_dialog = function(callback)
		local note_select = iup.text {
			value = "0",
			action = function(self)
				self = tostring(tonumber(self or 0) or 0)
			end,
			size = tostring(gkinterface.GetXResolution() * 0.1) .. "x",
		}
		
		local preset_list = iup.stationsublist {
			dropdown = "YES",
			size = tostring(gkinterface.GetXResolution() * 0.2) .. "x",
			action = function(self, t, i, c)
				if c == 1 then
					note_select.value = note_presets[i][1]
				end
			end,
		}
		
		for k, v in ipairs(note_presets) do
			preset_list[k] = v[2]
		end
		
		local diag = iup.dialog {
			topmost = "YES",
			fullscreen = "YES",
			bgcolor = "0 0 0 0 *",
			iup.zbox {
				all = "YES",
				iup.vbox {
					iup.canvas {
						button_cb = function(self, ...)
							local args = {...}
							if args[2] == 1 then
								iup.GetDialog(self):hide()
							else
								iup.Destroy(iup.GetDialog(self))
							end
						end,
						border = "NO",
						size = "FULLxFULL",
					},
				},
				iup.vbox {
					iup.fill { },
					iup.hbox {
						iup.fill { },
						iup.stationbuttonframe {
							color = "255 255 255 255 *",
							iup.vbox {
								margin = "6x6",
								iup.hbox {
									iup.label {
										title = bstr(6, "Select an index to load"),
									},
									iup.fill { },
									
									iup.stationbutton {
										title = bstr(7, "Cancel"),
										action = function(self)
											iup.GetDialog(self):hide()
											iup.Destroy(iup.GetDialog(self))
										end,
									},
								},
								iup.fill {
									size = "%1",
								},
								note_select,
								iup.fill {
									size = "%2",
								},
								iup.hbox {
									iup.fill { },
									iup.vbox {
										iup.label {
											title = bstr(8, "Presets:"),
										},
										preset_list,
									},
								},
								iup.fill {
									size = "%10",
								},
								iup.hbox {
									iup.fill { },
									iup.stationbutton {
										title = bstr(9, "Select"),
										action = function(self)
											callback(note_select.value)
											iup.GetDialog(self):hide()
											iup.Destroy(iup.GetDialog(self))
										end,
									},
								},
							},
						},
						iup.fill { },
					},
					iup.fill { },
					iup.fill { },
				},
			},
		}
		
		diag:map()
		diag:show()
	end
	
	local preview = iup.multiline {
		readonly = "YES",
		value = "",
		size = HUDSize(0.7, 0.3),
	}
	
	local diag = iup.dialog {
		fullscreen = "YES",
		topmost = "YES",
		bgcolor = "0 0 0",
		iup.vbox {
			iup.fill {
				size = "%10",
			},
			iup.hbox {
				iup.fill { },
				iup.stationnameframe {
					iup.vbox {
						alignment = "ACENTER",
						iup.fill {
							size = "%1",
						},
						iup.hbox {
							iup.label {
								title = bstr(1, "Clipboard Saver"),
							},
							iup.fill { },
							iup.stationbutton {
								title = bstr(10, "Return"),
								action = function(self)
									HideDialog(iup.GetDialog(self))
									iup.Destroy(iup.GetDialog(self))
								end,
							},
						},
						iup.fill {
							size = "%1",
						},
						iup.hbox {
							iup.stationbutton {
								title = bstr(11, "Find/Load a file index"),
								action = function()
									select_dialog(function(input)
										preview.value = LoadSystemNotes(tonumber(input))
									end)
								end,
							},
							iup.stationbutton {
								title = bstr(12, "Save to a file index"),
								action = function()
									select_dialog(function(input)
										SaveSystemNotes(preview.value, tonumber(input))
									end)
								end,
							},
							iup.fill { },
							iup.stationbutton {
								title = bstr(13, "Export to clipboard"),
								action = function()
									gkinterface.SetClipboardText(preview.value)
								end,
							},
							iup.stationbutton {
								title = bstr(14, "Import from clipboard"),
								action = function()
									preview.value = gkinterface.GetClipboardText()
								end,
							},
						},
						iup.fill {
							size = "%2",
						},
						preview,
						iup.fill {
							size = "%10",
						},
					},
				},
				iup.fill { },
			},
			iup.fill { },
		},
	}
	
	diag:map()
	ShowDialog(diag)
end

clip.config = clip.open

RegisterUserCommand("clipsave", clip.open)

if type(lib) == "table" and lib[0] == "LME" then
	lib.set_class("clipsaver", "0", clip)
	lib.require({{name = "babel", version = "0"}}, do_babel_support)
end